### R code from vignette source 'ST_intro.Rnw'
### Encoding: ISO8859-1

###################################################
### code chunk number 1: ST_intro.Rnw:36-37
###################################################
options(width=60, continue="  ")


###################################################
### code chunk number 2: ST_intro.Rnw:43-47
###################################################
library(SpatioTemporal)
library(plotrix)
library(maps)
library(fields)


###################################################
### code chunk number 3: ST_intro.Rnw:51-83
###################################################
##create colour-scheme
jet.colors <- colorRampPalette(c("#00007F", "blue", "#007FFF", 
  "cyan", "#7FFF7F", "yellow", "#FF7F00", "red", "#7F0000"))

##Function that plots coloured points
scatter <- function(x, y=NULL, value, colramp=jet.colors, 
    legend=TRUE, clim=range(value,na.rm=TRUE), cres=256,
    add=FALSE, truncate=TRUE, ...){
  if( missing(y) || is.null(y) ){
    y <- x[,2]; x <- x[,1];
  }
  ##Compute colour scales.
  Ind <- round((cres-1)*(value-clim[1]) / (clim[2]-clim[1])+1)
  if(truncate){
    Ind[Ind<1] <- 1
    Ind[Ind>cres] <- cres
  }else{
    Ind[Ind<1 | Ind>cres] <- NA
  }
  ##match length to the x and y data.
    Ind <- c(Ind,rep(NA,length(x)-length(Ind)))
  ##Do the plots
  if(add){
    points(x, y, col=jet.colors(cres)[Ind], ...)
  }else{
    plot(x, y, col=jet.colors(cres)[Ind], ...)
  }
  if(legend){
    image.plot(legend.only=TRUE, zlim=clim, 
               col=jet.colors(cres))
  }
}


###################################################
### code chunk number 4: ST_intro.Rnw:89-91
###################################################
data(mesa.data.raw)
names(mesa.data.raw)


###################################################
### code chunk number 5: ST_intro.Rnw:96-97
###################################################
head(mesa.data.raw$obs)


###################################################
### code chunk number 6: ST_intro.Rnw:100-101
###################################################
head(mesa.data.raw$X)


###################################################
### code chunk number 7: ST_intro.Rnw:107-112
###################################################
##extract observations and covariates
obs <- mesa.data.raw$obs
covars <- mesa.data.raw$X
##create STdata object
mesa.data <- createSTdata(obs, covars)


###################################################
### code chunk number 8: ST_intro.Rnw:116-117
###################################################
print(mesa.data)


###################################################
### code chunk number 9: figTimeSpace (eval = FALSE)
###################################################
## plot(mesa.data, "loc")


###################################################
### code chunk number 10: figMap (eval = FALSE)
###################################################
## plot(mesa.data$covars$long, mesa.data$covars$lat,
##      pch=c(24,25)[mesa.data$covars$type], 
##      bg=c("red","blue")[mesa.data$covars$type],
##      xlab="Longitude", ylab="Latitude")
## ##Add the map of LA
## map("county", "california", col="#FFFF0055", fill=TRUE, 
##     add=TRUE)
## ##Add a legend
## legend("bottomleft", c("AQS","FIXED"), pch=c(24,25), bty="n",
##        pt.bg=c("red","blue"))


###################################################
### code chunk number 11: ST_intro.Rnw:140-141
###################################################
plot(mesa.data, "loc")


###################################################
### code chunk number 12: ST_intro.Rnw:151-152
###################################################
plot(mesa.data$covars$long, mesa.data$covars$lat,
     pch=c(24,25)[mesa.data$covars$type], 
     bg=c("red","blue")[mesa.data$covars$type],
     xlab="Longitude", ylab="Latitude")
##Add the map of LA
map("county", "california", col="#FFFF0055", fill=TRUE, 
    add=TRUE)
##Add a legend
legend("bottomleft", c("AQS","FIXED"), pch=c(24,25), bty="n",
       pt.bg=c("red","blue"))


###################################################
### code chunk number 13: ST_intro.Rnw:162-168
###################################################
##extract a data matrix
D <- createDataMatrix(mesa.data)
##Run leave one out cross-validation to find smooth trends
SVD.cv <- SVDsmoothCV(D,1:5)
##Study the results
print(SVD.cv)


###################################################
### code chunk number 14: figSmoothCV (eval = FALSE)
###################################################
## ##plot the cv-results
## plot(SVD.cv)


###################################################
### code chunk number 15: figSmoothCVScatter (eval = FALSE)
###################################################
## plot(SVD.cv,pairs=TRUE)


###################################################
### code chunk number 16: ST_intro.Rnw:183-184
###################################################
##plot the cv-results
plot(SVD.cv)


###################################################
### code chunk number 17: ST_intro.Rnw:192-193
###################################################
plot(SVD.cv,pairs=TRUE)


###################################################
### code chunk number 18: ST_intro.Rnw:202-204
###################################################
mesa.data <- updateSTdataTrend(mesa.data, n.basis = 2)
print(mesa.data)


###################################################
### code chunk number 19: figTemporalTrends (eval = FALSE)
###################################################
## ##plot observations at some of the locations with the
## ##fitted smooth trends
## par(mfcol=c(4,1),mar=c(2.5,2.5,2,.5))
## plot(mesa.data, "obs", ID=5)
## plot(mesa.data, "res", ID=5)
## plot(mesa.data, "obs", ID=18)
## plot(mesa.data, "res", ID=18)


###################################################
### code chunk number 20: figTemporalACF (eval = FALSE)
###################################################
## par(mfcol=c(2,2),mar=c(2.5,2.5,3,.5))
## plot(mesa.data, "acf", ID=1)
## plot(mesa.data, "acf", ID=5)
## plot(mesa.data, "acf", ID=13)
## plot(mesa.data, "acf", ID=18)


###################################################
### code chunk number 21: ST_intro.Rnw:231-232
###################################################
##plot observations at some of the locations with the
##fitted smooth trends
par(mfcol=c(4,1),mar=c(2.5,2.5,2,.5))
plot(mesa.data, "obs", ID=5)
plot(mesa.data, "res", ID=5)
plot(mesa.data, "obs", ID=18)
plot(mesa.data, "res", ID=18)


###################################################
### code chunk number 22: ST_intro.Rnw:240-241
###################################################
par(mfcol=c(2,2),mar=c(2.5,2.5,3,.5))
plot(mesa.data, "acf", ID=1)
plot(mesa.data, "acf", ID=5)
plot(mesa.data, "acf", ID=13)
plot(mesa.data, "acf", ID=18)


###################################################
### code chunk number 23: ST_intro.Rnw:251-269
###################################################
##extract data
D <- createDataMatrix(mesa.data)
##create matrix that holds estimated beta:s
beta <- matrix(NA, dim(D)[2], dim(mesa.data$trend)[2])
beta.std <- beta
##get the trends
F <- mesa.data$trend
##this includes a data column, that we drop
F$date <- NULL
##linear regression of observations on the trends
for(i in 1:dim(D)[2]){
  tmp <- lm(D[,i] ~ as.matrix(F))
  beta[i,] <- coef(tmp)
  beta.std[i,] <- sqrt(diag(vcov(tmp)))
}
##Add names to the estimated betas
colnames(beta) <- c("beta.0","beta.1","beta.2")
rownames(beta) <- colnames(D)


###################################################
### code chunk number 24: betaMap (eval = FALSE)
###################################################
## par(mfcol=c(2,2))
## for(i in 1:3){
##   scatter(mesa.data$covars$long, mesa.data$covars$lat, 
##           beta[,i], pch=19)
##   map("county","california",add=TRUE)
## }


###################################################
### code chunk number 25: ST_intro.Rnw:287-288
###################################################
par(mfcol=c(2,2))
for(i in 1:3){
  scatter(mesa.data$covars$long, mesa.data$covars$lat, 
          beta[,i], pch=19)
  map("county","california",add=TRUE)
}


###################################################
### code chunk number 26: ST_intro.Rnw:296-297
###################################################
names(mesa.data$covars)


###################################################
### code chunk number 27: ST_intro.Rnw:303-318
###################################################
##define land-use covariates
LUR <-  list(c("log10.m.to.a1", "s2000.pop.div.10000", 
               "km.to.coast"), "km.to.coast", "km.to.coast")
##and covariance model
cov.beta <- list(covf="exp", nugget=FALSE)
cov.nu <- list(covf="exp", nugget=TRUE, random.effect=FALSE)
##which locations to use
locations <- list(coords=c("x","y"), long.lat=c("long","lat"), 
                  others="type")
##create object
mesa.model <- createSTmodel(mesa.data, LUR=LUR, ST=NULL,
                            cov.beta=cov.beta, cov.nu=cov.nu, 
                            locations=locations)
##inspect the resulting model
print(mesa.model)


###################################################
### code chunk number 28: ST_intro.Rnw:322-326
###################################################
##Some important dimensions of the model
dim <- loglikeSTdim(mesa.model)
x.init<-cbind(rep(2,dim$nparam.cov), 
              c(rep(c(1,-3),dim$m+1),-3))


###################################################
### code chunk number 29: ST_intro.Rnw:332-335 (eval = FALSE)
###################################################
## ##estimate parameters
## est.mesa.model <- estimate(mesa.model, x.init, 
##                            hessian.all=TRUE)


###################################################
### code chunk number 30: ST_intro.Rnw:340-341
###################################################
data(est.mesa.model)


###################################################
### code chunk number 31: ST_intro.Rnw:347-348
###################################################
print(est.mesa.model)


###################################################
### code chunk number 32: figEstPar (eval = FALSE)
###################################################
## par <- est.mesa.model$res.best$par.all
## par(mfrow=c(1,1),mar=c(13,2.5,.5,.5))
## plotCI(par$par, uiw=1.96*par$sd, ylab="", xlab="", xaxt="n")
## axis(1, 1:dim(par)[1], rownames(par), las=2)


###################################################
### code chunk number 33: ST_intro.Rnw:361-362
###################################################
par <- est.mesa.model$res.best$par.all
par(mfrow=c(1,1),mar=c(13,2.5,.5,.5))
plotCI(par$par, uiw=1.96*par$sd, ylab="", xlab="", xaxt="n")
axis(1, 1:dim(par)[1], rownames(par), las=2)


###################################################
### code chunk number 34: ST_intro.Rnw:373-374 (eval = FALSE)
###################################################
## EX <- predict(mesa.model, est.mesa.model$res.best$par, pred.var = TRUE)


###################################################
### code chunk number 35: ST_intro.Rnw:376-378
###################################################
data(pred.mesa.model)
EX <- pred.mesa.model


###################################################
### code chunk number 36: figPred (eval = FALSE)
###################################################
## par(mfrow=c(4,1),mar=c(2.5,2.5,2,.5))
## plot(EX, ID=1, STmodel=mesa.model, pred.var=TRUE)
## plot(EX, ID=10, STmodel=mesa.model, pred.var=TRUE)
## plot(EX, ID=17, STmodel=mesa.model, pred.var=TRUE)


###################################################
### code chunk number 37: figPred2 (eval = FALSE)
###################################################
## plot(EX, ID=17, STmodel=mesa.model, pred.var=TRUE, lwd=2)
## plot(EX, ID=17, pred.type="EX.mu", col="green", add=TRUE, lwd=2)
## plot(EX, ID=17, pred.type="EX.mu.beta", col="blue", add=TRUE, lwd=2)


###################################################
### code chunk number 38: ST_intro.Rnw:400-402
###################################################
par(mfrow=c(4,1),mar=c(2.5,2.5,2,.5))
plot(EX, ID=1, STmodel=mesa.model, pred.var=TRUE)
plot(EX, ID=10, STmodel=mesa.model, pred.var=TRUE)
plot(EX, ID=17, STmodel=mesa.model, pred.var=TRUE)
plot(EX, ID=17, STmodel=mesa.model, pred.var=TRUE, lwd=2)
plot(EX, ID=17, pred.type="EX.mu", col="green", add=TRUE, lwd=2)
plot(EX, ID=17, pred.type="EX.mu.beta", col="blue", add=TRUE, lwd=2)


###################################################
### code chunk number 39: betaComp (eval = FALSE)
###################################################
## par(mfcol=c(2,2),mar=c(4.5,4.5,2,.5))
## for(i in 1:3){
##   plotCI(x=beta[,i], y=EX$beta$EX[,i], pch=NA,
##          uiw=1.96*sqrt( diag(EX$beta$VX[,i]) ),
##          main=colnames(EX$beta$EX)[i],
##          xlab="Empirical estimate",
##          ylab="Spatio-Temporal Model")
##   plotCI(x=beta[,i], y=EX$beta$EX[,i], pch=NA,
##          uiw=1.96*beta.std[,i], err="x", add=TRUE)
##   points(beta[,i], EX$beta$EX[,i], pch=19, cex=1, col="red")
##   abline(0,1)
## }


###################################################
### code chunk number 40: ST_intro.Rnw:429-430
###################################################
par(mfcol=c(2,2),mar=c(4.5,4.5,2,.5))
for(i in 1:3){
  plotCI(x=beta[,i], y=EX$beta$EX[,i], pch=NA,
         uiw=1.96*sqrt( diag(EX$beta$VX[,i]) ),
         main=colnames(EX$beta$EX)[i],
         xlab="Empirical estimate",
         ylab="Spatio-Temporal Model")
  plotCI(x=beta[,i], y=EX$beta$EX[,i], pch=NA,
         uiw=1.96*beta.std[,i], err="x", add=TRUE)
  points(beta[,i], EX$beta$EX[,i], pch=19, cex=1, col="red")
  abline(0,1)
}


###################################################
### code chunk number 41: ST_intro.Rnw:440-442
###################################################
Ind.cv <- createCV(mesa.model, groups=10, min.dist=.1)
table(Ind.cv)


###################################################
### code chunk number 42: CVmap (eval = FALSE)
###################################################
## I.col <- sapply(split(mesa.model$obs$ID, Ind.cv), unique)
## I.col <- apply(sapply(I.col, function(x) mesa.model$locations$ID
##                %in% x), 1, function(x) if(sum(x)==1) which(x) else 0)
## plot(mesa.model$locations$long, mesa.model$locations$lat,
##      pch=23+floor(I.col/max(I.col)+.5), bg=I.col)
## map("county","california",add=TRUE)


###################################################
### code chunk number 43: ST_intro.Rnw:456-457
###################################################
I.col <- sapply(split(mesa.model$obs$ID, Ind.cv), unique)
I.col <- apply(sapply(I.col, function(x) mesa.model$locations$ID
               %in% x), 1, function(x) if(sum(x)==1) which(x) else 0)
plot(mesa.model$locations$long, mesa.model$locations$lat,
     pch=23+floor(I.col/max(I.col)+.5), bg=I.col)
map("county","california",add=TRUE)


###################################################
### code chunk number 44: ST_intro.Rnw:473-479 (eval = FALSE)
###################################################
## ##estimate different parameters for each CV-group
## est.cv.mesa <- estimateCV(mesa.model, x.init, Ind.cv)
## ##compute predictions at the different sites,
## ##given the estimated parameters
## pred.cv.mesa <- predictCV(mesa.model, est.cv.mesa$par.cov, 
##                           est.cv.mesa$Ind.cv)


###################################################
### code chunk number 45: ST_intro.Rnw:485-486
###################################################
data(CV.mesa.model)


###################################################
### code chunk number 46: ST_intro.Rnw:491-492
###################################################
print(est.cv.mesa)


###################################################
### code chunk number 47: figCVpar (eval = FALSE)
###################################################
## par(mfrow=c(1,1), mar=c(13,2.5,.5,.5), las=2)
## boxplot(est.cv.mesa, plot.type="all")
## ##we've previously extracted the estimated parameters
## points(par$par, col=2, pch=19)


###################################################
### code chunk number 48: ST_intro.Rnw:505-506
###################################################
par(mfrow=c(1,1), mar=c(13,2.5,.5,.5), las=2)
boxplot(est.cv.mesa, plot.type="all")
##we've previously extracted the estimated parameters
points(par$par, col=2, pch=19)


###################################################
### code chunk number 49: ST_intro.Rnw:516-522 (eval = FALSE)
###################################################
## ##look at the predictions at 4 sites
## par(mfcol=c(4,1),mar=c(2.5,2.5,2,.5))
## plotCV(pred.cv, 1, mesa.data.model)
## plotCV(pred.cv, 5, mesa.data.model)
## plotCV(pred.cv, 13, mesa.data.model)
## plotCV(pred.cv, 18, mesa.data.model)


###################################################
### code chunk number 50: ST_intro.Rnw:526-527
###################################################
summary(pred.cv.mesa)


###################################################
### code chunk number 51: ST_intro.Rnw:533-538 (eval = FALSE)
###################################################
## par(mfcol=c(1,1),mar=c(4.5,4.5,2,.5))
## plot(pred.cv$pred.obs[,"obs"], pred.cv$pred.obs[,"pred"], 
##      xlab="observations",ylab="predictions",pch=19,cex=.1,
##      col=mesa.data.model$obs$idx)
## abline(0,1)


