### R code from vignette source 'Tutorial.Rnw'
### Encoding: ISO8859-1

###################################################
### code chunk number 1: Tutorial.Rnw:52-53
###################################################
options(width=60, continue="  ")


###################################################
### code chunk number 2: Tutorial.Rnw:311-313 (eval = FALSE)
###################################################
## ##A qqplot for some N(0,1) random numbers
## qqnorm(rnorm(100))


###################################################
### code chunk number 3: Tutorial.Rnw:317-319
###################################################
##Summary of 100 N(0,1) numbers.
summary(rnorm(100))


###################################################
### code chunk number 4: Tutorial.Rnw:341-343
###################################################
library(SpatioTemporal)
data(mesa.data)


###################################################
### code chunk number 5: Tutorial.Rnw:352-358
###################################################
##Load the SpatioTemporal package
library(SpatioTemporal)
##A package used for some plots in this tutorial (plotCI)
library(plotrix) 
###The maps to provide reference maps
library(maps)


###################################################
### code chunk number 6: Tutorial.Rnw:365-367
###################################################
###Load the data
data(mesa.data)


###################################################
### code chunk number 7: Tutorial.Rnw:378-380
###################################################
class(mesa.data)
names(mesa.data)


###################################################
### code chunk number 8: Tutorial.Rnw:389-390
###################################################
head(mesa.data$covars)


###################################################
### code chunk number 9: figMap (eval = FALSE)
###################################################
## ###Plot the locations, see \autoref&fig:map;
## par(mfrow=c(1,1))
## plot(mesa.data$covars$long, mesa.data$covars$lat,
##      pch=24, bg=c("red","blue")[mesa.data$covars$type],
##      xlab="Longitude", ylab="Latitude")
## 
## ###Add the map of LA
## map("county", "california", col="#FFFF0055", fill=TRUE, 
##     add=TRUE)
## 
## ##Add a legend
## legend("bottomleft", c("AQS","FIXED"), pch=24, bty="n",
##        pt.bg=c("red","blue"))


###################################################
### code chunk number 10: Tutorial.Rnw:436-437
###################################################
###Plot the locations, see \autoref&fig:map;
par(mfrow=c(1,1))
plot(mesa.data$covars$long, mesa.data$covars$lat,
     pch=24, bg=c("red","blue")[mesa.data$covars$type],
     xlab="Longitude", ylab="Latitude")

###Add the map of LA
map("county", "california", col="#FFFF0055", fill=TRUE, 
    add=TRUE)

##Add a legend
legend("bottomleft", c("AQS","FIXED"), pch=24, bty="n",
       pt.bg=c("red","blue"))


###################################################
### code chunk number 11: Tutorial.Rnw:446-447
###################################################
head(mesa.data$trend)


###################################################
### code chunk number 12: Tutorial.Rnw:465-466
###################################################
range(mesa.data$trend$date)


###################################################
### code chunk number 13: Tutorial.Rnw:473-474
###################################################
head(mesa.data$obs)


###################################################
### code chunk number 14: Tutorial.Rnw:501-503
###################################################
dim(mesa.data$SpatioTemp)
mesa.data$SpatioTemp[1:5,1:5,]


###################################################
### code chunk number 15: Tutorial.Rnw:528-529
###################################################
str(dimnames(mesa.data$SpatioTemp))


###################################################
### code chunk number 16: Tutorial.Rnw:533-535 (eval = FALSE)
###################################################
## as.character(sort(unique(c(mesa.data$obs$date,
##     mesa.data$trend$date))))


###################################################
### code chunk number 17: Tutorial.Rnw:539-540
###################################################
dimnames(mesa.data$SpatioTemp)[[3]]


###################################################
### code chunk number 18: Tutorial.Rnw:553-554
###################################################
print(mesa.data)


###################################################
### code chunk number 19: figTimeSpace (eval = FALSE)
###################################################
## ###Plot when observations occurr, see \autoref&fig:time_space;
## par(mfcol=c(1,1),mar=c(4.3,4.3,1,1))
## plot(mesa.data, "loc")


###################################################
### code chunk number 20: Tutorial.Rnw:588-589
###################################################
###Plot when observations occurr, see \autoref&fig:time_space;
par(mfcol=c(1,1),mar=c(4.3,4.3,1,1))
plot(mesa.data, "loc")


###################################################
### code chunk number 21: Tutorial.Rnw:600-602
###################################################
data(mesa.data.raw)
names(mesa.data.raw)


###################################################
### code chunk number 22: Tutorial.Rnw:615-616
###################################################
head(mesa.data.raw$X)


###################################################
### code chunk number 23: Tutorial.Rnw:628-629
###################################################
mesa.data.raw$obs[1:6,1:5]


###################################################
### code chunk number 24: Tutorial.Rnw:642-643
###################################################
mesa.data.raw$lax.conc.1500[1:6,1:5]


###################################################
### code chunk number 25: Tutorial.Rnw:657-666
###################################################
obs <- mesa.data.raw$obs
covars <- mesa.data.raw$X
##list with the spatio-temporal covariates
ST.list <- list(lax.conc.1500=mesa.data.raw$lax.conc.1500)

##create STdata object
mesa.data.scratch <- createSTdata(obs, covars, 
  SpatioTemporal=ST.list,n.basis=2)
names(mesa.data.scratch)


###################################################
### code chunk number 26: Tutorial.Rnw:677-678
###################################################
class(mesa.data.scratch)


###################################################
### code chunk number 27: Tutorial.Rnw:689-695
###################################################
##extract a data matrix
D <- createDataMatrix(mesa.data)
##and study the data
dim(D)
D[1:6,1:5]
colnames(D)


###################################################
### code chunk number 28: Tutorial.Rnw:707-714
###################################################
##subset the data
ID.subset <-mesa.data$covars[mesa.data$covars$type ==
                               "AQS",]$ID
D2 <- createDataMatrix(mesa.data, subset=ID.subset)
##and study the result
dim(D2)
colnames(D2)


###################################################
### code chunk number 29: Tutorial.Rnw:730-732
###################################################
##Run leave one out cross-validation to find smooth trends
SVD.cv <- SVDsmoothCV(D,1:5)


###################################################
### code chunk number 30: Tutorial.Rnw:801-802
###################################################
print(SVD.cv)


###################################################
### code chunk number 31: figSVDcv (eval = FALSE)
###################################################
## ##Plotting the smooth trends CV results, see \autoref&fig:svd_cv;
## plot(SVD.cv)


###################################################
### code chunk number 32: Tutorial.Rnw:822-823
###################################################
##Plotting the smooth trends CV results, see \autoref&fig:svd_cv;
plot(SVD.cv)


###################################################
### code chunk number 33: figBICpairs (eval = FALSE)
###################################################
## ##Plotting BIC values, see \autoref&fig:BIC_pairs;
## par(mfcol=c(1,1),mar=c(4,4,.5,.5))
## pairs(SVD.cv$BIC.all, pane = 
##       function(x,y){points(x,y)
##                     abline(0,1)})


###################################################
### code chunk number 34: Tutorial.Rnw:844-845
###################################################
##Plotting BIC values, see \autoref&fig:BIC_pairs;
par(mfcol=c(1,1),mar=c(4,4,.5,.5))
pairs(SVD.cv$BIC.all, pane = 
      function(x,y){points(x,y)
                    abline(0,1)})


###################################################
### code chunk number 35: Tutorial.Rnw:859-863
###################################################
##compute new temporal smooths
F <- calcSmoothTrends(mesa.data, n.basis=2)
##and add the new trends to the data structure
mesa.data$trend <- F$trend


###################################################
### code chunk number 36: Tutorial.Rnw:869-871
###################################################
##compute new temporal smooths
mesa.data <- updateSTdataTrend(mesa.data, n.basis=2)


###################################################
### code chunk number 37: figsmooth_trends (eval = FALSE)
###################################################
## ##plot the observations at two of the locations along
## ##with the fitted smooth trends, see \autoref&fig:smooth_trends;
## par(mfrow=c(4,1),mar=c(2.5,2.5,2,.5))
## plot(mesa.data, "obs", ID=5)
## plot(mesa.data, "obs", ID=18)
## 
## ##also plot the residuals
## plot(mesa.data, "res", ID=5)
## plot(mesa.data, "res", ID=18)


###################################################
### code chunk number 38: Tutorial.Rnw:891-892
###################################################
##plot the observations at two of the locations along
##with the fitted smooth trends, see \autoref&fig:smooth_trends;
par(mfrow=c(4,1),mar=c(2.5,2.5,2,.5))
plot(mesa.data, "obs", ID=5)
plot(mesa.data, "obs", ID=18)

##also plot the residuals
plot(mesa.data, "res", ID=5)
plot(mesa.data, "res", ID=18)


###################################################
### code chunk number 39: figAutocorr (eval = FALSE)
###################################################
## ##Autocorrelation of the residuals at four locations,
## ##see \autoref&fig:autocorr;
## par(mfcol=c(2,2),mar=c(2.5,2.5,3,.5))
## plot(mesa.data, "acf", ID=1)
## plot(mesa.data, "acf", ID=5)
## plot(mesa.data, "acf", ID=13)
## plot(mesa.data, "acf", ID=18)


###################################################
### code chunk number 40: Tutorial.Rnw:932-933
###################################################
##Autocorrelation of the residuals at four locations,
##see \autoref&fig:autocorr;
par(mfcol=c(2,2),mar=c(2.5,2.5,3,.5))
plot(mesa.data, "acf", ID=1)
plot(mesa.data, "acf", ID=5)
plot(mesa.data, "acf", ID=13)
plot(mesa.data, "acf", ID=18)


###################################################
### code chunk number 41: Tutorial.Rnw:953-973
###################################################
##create data matrix
D <- createDataMatrix(mesa.data)
beta <- matrix(NA,dim(D)[2], dim(mesa.data$trend)[2])
beta.std <- beta
##extact the temporal trends
F <- mesa.data$trend
##drop the date column
F$date <- NULL

##estimate the beta-coeficients at each location
for(i in 1:dim(D)[2]){
  tmp <- lm(D[,i] ~ as.matrix(F))
  beta[i,] <- coef(tmp)
  beta.std[i,] <- sqrt(diag(vcov(tmp)))
}

##Add names to the estimated betas
colnames(beta) <- c("const",colnames(F))
rownames(beta) <- colnames(D)
dimnames(beta.std) <- dimnames(beta)


###################################################
### code chunk number 42: Tutorial.Rnw:976-978
###################################################
##examine the beta fields
head(beta)


###################################################
### code chunk number 43: Tutorial.Rnw:981-982
###################################################
head(beta.std)


###################################################
### code chunk number 44: Tutorial.Rnw:1019-1025
###################################################
##define land-use covariates
LUR <-  list(c("log10.m.to.a1", "s2000.pop.div.10000", "km.to.coast"),
             "km.to.coast", "km.to.coast")
##and covariance model
cov.beta <- list(covf="exp", nugget=FALSE)
cov.nu <- list(covf="exp", nugget=TRUE, random.effect=FALSE)


###################################################
### code chunk number 45: Tutorial.Rnw:1039-1042
###################################################
##which locations to use
locations <- list(coords=c("x","y"), long.lat=c("long","lat"), 
  others="type")


###################################################
### code chunk number 46: Tutorial.Rnw:1047-1051
###################################################
##create object
mesa.model <- createSTmodel(mesa.data, LUR=LUR, cov.beta=cov.beta,
                            cov.nu=cov.nu, locations=locations)
print(mesa.model)


###################################################
### code chunk number 47: Tutorial.Rnw:1067-1070
###################################################
cov.beta2 <- list(covf=c("exp","exp2","iid"), nugget=c(FALSE,FALSE,TRUE))
mesa.model2 <- updateCovf(mesa.model, cov.beta=cov.beta2)
print(mesa.model2)


###################################################
### code chunk number 48: Tutorial.Rnw:1081-1083
###################################################
model.dim <- loglikeSTdim(mesa.model)
model.dim


###################################################
### code chunk number 49: Tutorial.Rnw:1095-1099
###################################################
##Setting up the initial parameter values for optimization
x.init <- cbind(rep(2,model.dim$nparam.cov), 
                c(rep(c(1,-3),model.dim$m+1),-3))
x.init


###################################################
### code chunk number 50: Tutorial.Rnw:1114-1115
###################################################
loglikeSTnames(mesa.model,all=FALSE)


###################################################
### code chunk number 51: Tutorial.Rnw:1122-1125
###################################################
##Add names to the initial values
rownames(x.init) <- loglikeSTnames(mesa.model,all=FALSE)
x.init


###################################################
### code chunk number 52: Tutorial.Rnw:1132-1135 (eval = FALSE)
###################################################
## ##Estimate model parameters
## est.mesa.model <- estimate(mesa.model, x.init, type="p", 
##     hessian.all=TRUE)


###################################################
### code chunk number 53: Tutorial.Rnw:1184-1186
###################################################
##Get the precomputed optimisation results instead.
data(est.mesa.model)


###################################################
### code chunk number 54: Tutorial.Rnw:1213-1215
###################################################
loglikeST(est.mesa.model$res.best$par, mesa.model)
est.mesa.model$res.best$value


###################################################
### code chunk number 55: Tutorial.Rnw:1224-1226
###################################################
##Optimisation status message
print(est.mesa.model)


###################################################
### code chunk number 56: Tutorial.Rnw:1242-1243
###################################################
names(est.mesa.model)


###################################################
### code chunk number 57: Tutorial.Rnw:1254-1257
###################################################
names(est.mesa.model$res.best)
names(est.mesa.model$res.all[[1]])
names(est.mesa.model$res.all[[2]])


###################################################
### code chunk number 58: Tutorial.Rnw:1297-1299
###################################################
##extract the estimated parameters and approximate uncertainties
x <- est.mesa.model$res.best$par.all


###################################################
### code chunk number 59: figParCI (eval = FALSE)
###################################################
## ##plot the estimated parameters with uncertainties
## par(mfrow=c(1,1),mar=c(13.5,2.5,.5,.5))
## plot(x$par, ylim=range(c( x$par-1.96*x$sd, x$par+1.96*x$sd )),
##      xlab="", xaxt="n")
## points(x$par - 1.96*x$sd, pch=3)
## points(x$par + 1.96*x$sd, pch=3)
## axis(1, 1:length(x$par), rownames(x), las=2)


###################################################
### code chunk number 60: Tutorial.Rnw:1318-1319
###################################################
##plot the estimated parameters with uncertainties
par(mfrow=c(1,1),mar=c(13.5,2.5,.5,.5))
plot(x$par, ylim=range(c( x$par-1.96*x$sd, x$par+1.96*x$sd )),
     xlab="", xaxt="n")
points(x$par - 1.96*x$sd, pch=3)
points(x$par + 1.96*x$sd, pch=3)
axis(1, 1:length(x$par), rownames(x), las=2)


